En este directorio puedes añadir capturas de pantalla o GIFs que muestren la ejecución de los notebooks. Para mantener ligero el repositorio, estas imágenes no se incluyen en el control de versiones.
